library(memisc)
library(survey)
library(cnlmisc)

options(signif.symbols=c(
          "***"=.001,
          "**"=.01,
          "*"=.05,
          "†"=.10
          ))

## data <- spss.system.file("TrueFinalWorkingMasterOct2012.sav")
## data <- subset(data, select=c(q22,q25,q26,q28,q29,q30,q35,q36,q38,q39,q42,q1,q54,q57,q60,q59,q61,q56,q47,q48,q49,q4,q44,q55,masterwe))

load('dataset-wp-dist7.Rdata')

dist7 <- as.data.set(data)
dist7 <- subset(dist7, subset=!is.na(masterwe))

## Summaries of interest

## Knowledge of being in new district
x <- Table(dist7$q22, weights=dist7$masterwe, percentage=TRUE)

lx <- toLatex(x, digits=1)
write(lx, file="table-districtknow.tex")

## counties in new district
x <- Table(dist7$q28, weights=dist7$masterwe, percentage=TRUE)

lx <- toLatex(x, digits=1)
write(lx, file="table-isgeorgetown.tex")

x <- Table(dist7$q29, weights=dist7$masterwe, percentage=TRUE)

lx <- toLatex(x, digits=1)
write(lx, file="table-isyork.tex")

x <- Table(dist7$q30, weights=dist7$masterwe, percentage=TRUE)

lx <- toLatex(x, digits=1)
write(lx, file="table-issumter.tex")

## Better off with district

x <- Table(dist7$q25, weights=dist7$masterwe, percentage=TRUE)

lx <- toLatex(x, digits=1)
write(lx, file="table-districtbetter.tex")

## Favored part of district

x <- Table(dist7$q26, weights=dist7$masterwe, percentage=TRUE)

lx <- toLatex(x, digits=1)
write(lx, file="table-whobenefitmore.tex")

q27

## Knowledge items

## Violent Crime last 30 years
dist7$q35right <- ifelse(dist7$q35=="Decreased",1,0)

## Teen pregnancy last 30 years
dist7$q36right <- ifelse(dist7$q36=="Decreased",1,0)

## Lt Governor
dist7$q38right <- ifelse(dist7$q38=="Glenn McConnell (or 'McConnell')",1,0)
## SCOTUS
dist7$q39right <- ifelse(dist7$q39=="John Roberts (or 'Roberts')",1,0)

dist7$knowledge <- (dist7$q35right + dist7$q36right + dist7$q38right + dist7$q39right)

## Knew was in district
dist7$q22knew <- ifelse(dist7$q22=="Aware and KNEW lived in",1,0)
dist7$q22knew[dist7$q22=="Refused"] <- NA

dist7$q22newdist <- ifelse(dist7$q22=="Not Aware",0,1)
dist7$q22newdist[dist7$q22=="Refused"] <- NA


## Pol awareness
dist7$aware <- 4-as.integer(dist7$q1)

dist7$educ <- as.integer(dist7$q54)
dist7$educ[dist7$educ==9] <- NA

dist7$age <- as.integer(dist7$q57)
dist7$age[dist7$age==00] <- NA

dist7$female <- ifelse(dist7$q60=="Female",1,0)
dist7$female[dist7$q60=="Not sure"] <- NA

dist7$income <- as.integer(dist7$q59)
dist7$income[dist7$income==99] <- NA

dist7$ivrknow <- 7-as.integer(dist7$q61)
dist7$ivrknow[dist7$ivrknow < 0] <- NA

dist7$black <- ifelse(dist7$q56=="African American",1,0)
dist7$black[dist7$q56=="Don't Know / Refused"] <- NA

##dsurvey <- svydesign(id=~id, weights=~masterwe, data=dist7)

res <- glm(q22knew ~ knowledge + educ + aware + age + female + black+ ivrknow +
           income, weights=masterwe, data=dist7, family=binomial)
summary(res)

res2 <- glm(q22newdist ~ knowledge + educ + aware + age + female + black+ ivrknow+
           income, weights=masterwe, data=dist7, family=binomial)
summary(res2)

lres <- toLatex(mtable("Knew was in district"=res,"Knew district existed"=res2))
write(lres, file="knowdist-model.tex")

epcp(res)
epcp(res2)

## Better off model

dist7$betteroff <- ifelse(dist7$q25 == "Better", 1, 0)
dist7$betteroff[dist7$q25=="Refused to Answer"] <- NA

dist7$horry <- ifelse(dist7$q42 == "Horry ('H' is silent; pronounced Orry)", 1, 0)
dist7$horry[dist7$q42=="Refused"] <-  NA
dist7$horry[dist7$q42=="Don't Know/ Not sure"] <-  NA

dist7$county <- as.factor(dist7$q42)
dist7$county[dist7$q42=="Refused"] <-  NA
dist7$county[dist7$q42=="Don't Know/ Not sure"] <-  NA

dist7$coastal <- ifelse(dist7$county %in% c("Georgetown", "Horry ('H' is silent; pronounced Orry)"), 1, 0)

dist7$pid7a <- as.integer(recode(dist7$q47, 1 <- 'Strong',
                                 2 <- 'Not so strong', otherwise=0))
dist7$pid7b <- as.integer(recode(dist7$q48, 7 <- 'Strong',
                                 6 <- 'Not so strong', otherwise=0))
dist7$pid7c <- as.integer(recode(dist7$q49, 3 <- 'Lean Democratic',
                                 4 <- 'Neither',
                                 5 <- 'Lean Republican', otherwise=0))
dist7$pid7 <- (dist7$pid7a + dist7$pid7b + dist7$pid7c)
dist7$pid7[dist7$pid7 == 0] <- NA

dist7$gop <- ifelse(dist7$pid7 >= 5, 1, 0)

resbetter <- glm(betteroff ~ knowledge + educ + aware + age + female + black +
                 ivrknow + income + coastal + gop,
                 weights=masterwe, data=dist7, family=binomial)
summary(resbetter)

epcp(resbetter)

lres <- toLatex(mtable(resbetter))
write(lres, file="districtbetter-model.tex")

## Vote model

dist7$voterice <- ifelse(dist7$q4=="Rice - lean" | dist7$q4=="Rice - vote", 1, 0)
dist7$voterice[dist7$q4 %in% c("Refuse", "Not Sure", "Someone else")] <- NA

Table(dist7$voterice, weights=dist7$masterwe, percentage=TRUE)

tab <- xtabs(masterwe ~ voterice + black, data=dist7)
round(sweep(tab, 2, apply(tab, 2, sum), "/")*100, 1)

tab <- xtabs(masterwe ~ voterice + PIDwithLean, data=dist7)
round(sweep(tab, 2, apply(tab, 2, sum), "/")*100, 1)

dist7$ideology <- as.integer(dist7$q44)
dist7$ideology[as.integer(dist7$q44) > 5] <- NA

dist7$married <- ifelse(dist7$q55 == "Currently married", 1, 0)
dist7$married[as.integer(dist7$q55 > 6)] <- NA

resvote <- glm(voterice ~ educ + age + female + black +
               income + pid7 + ideology + married,
               weights=masterwe, data=dist7, family=binomial)
summary(resvote)

epcp(resvote)

lres <- toLatex(mtable(resvote))
write(lres, file="vote-model.tex")
